@@ -5,7 +5,7 @@ import streamlit.components.v1 as components
 # the component, and True when we're ready to package and distribute it.
 # (This is, of course, optional - there are innumerable ways to manage your
 # release process.)
-_RELEASE = True
+_RELEASE = False
 
 # Declare a Streamlit component. `declare_component` returns a function
 # that is used to create instances of the component. We're naming this
@@ -91,8 +91,8 @@ if not _RELEASE:
         '2':['ok','I', 'figured','out']},
     }
     pos_data = {'NLTK_POS':{'1':[('Use', 'NOUN'), ('Bootstrap', 'NOUN'), ('’', 'NOUN'), ('s', 'NOUN'), ('custom', 'NOUN'), ('button', 'NOUN'), ('styles', 'NOUN'), ('for', 'ADP'), ('actions', 'NOUN'), ('in', 'ADP'), ('forms', 'NOUN'), (',', '.'), ('dialogs', 'NOUN'), (',', '.'), ('and', 'CONJ'), ('more', 'ADV'), ('with', 'ADP'), ('support', 'NOUN'), ('for', 'ADP'), ('multiple', 'NOUN'), ('sizes', 'NOUN'), (',', '.'), ('states', 'NOUN'), (',', '.'), ('and', 'CONJ'), ('more', 'ADV'), ('.', '.')]}}
-
+    ok={'SpaCy_POS_tags': [{'1': [('This', 'PRON'), ('is', 'AUX'), ('an', 'DET'), ('example', 'NOUN'), ('.', 'PUNCT')]}]}
     viz_tokens_component(data,True, key="foo")
-    viz_tokens_component(pos_data,False, key="foo1")
+    viz_tokens_component(ok,False, key="foo1")
     
     
